@@ -53,6 +53,7 @@ class PDF::Reader
     end
 
     def basefont=(font)
+      $stderr.puts "Font#basefont= is deprecated and will be removed in the 2.0 release"
       @encoding ||= default_encoding(font)
       @basefont = font
     end
@@ -105,7 +106,7 @@ class PDF::Reader
       elsif @subtype == :Type3
         PDF::Reader::WidthCalculator::TypeOneOrThree.new(self)
       elsif @subtype == :TrueType
-        PDF::Reader::WidthCalculator::TypeOneOrThree.new(self)
+        PDF::Reader::WidthCalculator::TrueType.new(self)
       elsif @subtype == :CIDFontType0 || @subtype == :CIDFontType2
         PDF::Reader::WidthCalculator::Composite.new(self)
       else
