@@ -6,18 +6,18 @@ describe PDF::Reader::Filter::AsciiHex do
   it "should filter a ASCIIHex stream correctly" do
     filter = PDF::Reader::Filter::AsciiHex.new
     encoded_data = "<52756279>"
-    filter.filter(encoded_data).should eql("Ruby")
+    expect(filter.filter(encoded_data)).to eql("Ruby")
   end
 
   it "should filter a ASCIIHex stream missing delimiters" do
     filter = PDF::Reader::Filter::AsciiHex.new
     encoded_data = "52756279"
-    filter.filter(encoded_data).should eql("Ruby")
+    expect(filter.filter(encoded_data)).to eql("Ruby")
   end
 
   it "should filter a ASCIIHex stream with an odd number of nibbles" do
     filter = PDF::Reader::Filter::AsciiHex.new
     encoded_data = "5275627"
-    filter.filter(encoded_data).should eql("Rubp")
+    expect(filter.filter(encoded_data)).to eql("Rubp")
   end
 end
