@@ -8,7 +8,7 @@ describe PDF::Reader::Reference, "hash method" do
     one = PDF::Reader::Reference.new(1,0)
     two = PDF::Reader::Reference.new(1,0)
 
-    one.hash.should == two.hash
+    expect(one.hash).to eq(two.hash)
   end
 
 end
@@ -18,20 +18,20 @@ describe PDF::Reader::Reference, "== method" do
   it "should return true for the same object" do
     one = PDF::Reader::Reference.new(1,0)
 
-    (one == one).should be_true
+    expect(one == one).to be_truthy
   end
 
   it "should return true for 2 identical objects" do
     one = PDF::Reader::Reference.new(1,0)
     two = PDF::Reader::Reference.new(1,0)
 
-    (one == two).should be_true
+    expect(one == two).to be_truthy
   end
 
   it "should return false if one object isn't a Reference" do
     one = PDF::Reader::Reference.new(1,0)
 
-    (one == "two").should be_false
+    expect(one == "two").to be_falsey
   end
 
 end
